@@ -176,11 +176,11 @@ def success(request):
         invoice = data.get('order_id')
         transaction = data.get('transaction_id')
         if not invoice or not transaction:
-            return bad_or_missing(request, _('Bad request.'))
+            return HttpResponse(_('Bad request.')
         result_message = data.get('result_message')
         order = Order.objects.get(pk=invoice)
     except Order.DoesNotExist:
-        return bad_or_missing(request, _('Your order has already been processed.'))
+        return HttpResponse(_('Invalid order.'))
 
 #    del request.session['orderID']
     context = RequestContext(request,
@@ -200,12 +200,15 @@ def failure(request):
     """
     try:
         data = request.POST
-        invoice = data['order_id']
         result_message = data['result_message']
+        invoice = data.get('order_id')
+        if not invoice:
+            return HttpResponse(_('Bad request.')
+        result_message = data.get('result_message')
         order = Order.objects.get(pk=invoice)
 
     except Order.DoesNotExist:
-        return bad_or_missing(request, _('Your order has already been processed.'))
+        return HttpResponse(_('Order does not exist.'))
 
     context = RequestContext(request, 
         {
